#! /bin/sh
# Convert a UNIX man page to strictly-conformant HTML 2.0, 3.0, or 3.2.
#
# Usage:
#
#	man2html [-v VAR=value] [ -outdir dirname ] files(s)
#
# Each input file is converted to an output file of the same basename,
# but with extension .html, and written into the specified output
# directory (default: the current directory).
#
# Variables defined by -v VAR=value are passed directly to man2html.awk.
# The only relevant variable is HTML, which takes values 2, 3, or 3.2.
#
# [14-Dec-1996]

FILES=
OUTDIR=.
VARS=
while test $# -gt 0
do
	case $1 in
	-o*)	OUTDIR=$2
		shift
		;;
	-v)	VARS="$VARS -v $2"
		shift
		;;
	*)			# everything else is assumed to be a filename
		FILES="$FILES $1"
		;;
	esac
	shift
done

GAWK=/usr/local/bin/gawk
MAN2HTML=/usr/local/share/lib/man2html/man2html.awk

for f in $FILES
do
	outfile="$OUTDIR/`basename $f | sed -e s/[.].*$//`.html"
#	echo ""
#	echo "------------------------------------------------------------------------"
# Prettyprinted version:
#	$GAWK -f $MAN2HTML $f | html-pretty -n -f $outfile -i 2 >$outfile
# Non-prettyprinted version:
	$GAWK -f $MAN2HTML $VARS $f >$outfile
	echo $outfile
done

